@@ -5,11 +5,12 @@ import click
 from great_expectations import DataContext
 from great_expectations import exceptions as ge_exceptions
 from great_expectations.cli.util import cli_message
+from great_expectations.core.usage_statistics.usage_statistics import send_usage_message
 
 
 @click.group()
 def project():
-    """project operations"""
+    """Project operations"""
     pass
 
 
@@ -23,7 +24,13 @@ def project():
 def project_check_config(directory):
     """Check a config for validity and help with migrations."""
     cli_message("Checking your config files for validity...\n")
-    is_config_ok, error_message = do_config_check(directory)
+    is_config_ok, error_message, context = do_config_check(directory)
+    if context:
+        send_usage_message(
+            data_context=context,
+            event="cli.project.check_config",
+            success=True
+        )
     if not is_config_ok:
         cli_message("Unfortunately, your config appears to be invalid:\n")
         cli_message("<red>{}</red>".format(error_message))
@@ -34,8 +41,8 @@ def project_check_config(directory):
 
 def do_config_check(target_directory):
     try:
-        DataContext(context_root_dir=target_directory)
-        return True, None
+        context = DataContext(context_root_dir=target_directory)
+        return True, None, context
     except (
         ge_exceptions.InvalidConfigurationYamlError,
         ge_exceptions.InvalidTopLevelConfigKeyError,
@@ -45,4 +52,4 @@ def do_config_check(target_directory):
         ge_exceptions.DataContextError,
         ge_exceptions.PluginClassNotFoundError,
     ) as err:
-        return False, err.message
+        return False, err.message, None
